import { Component, OnInit, Input, OnChanges, Output, EventEmitter } from '@angular/core';
import { Store, select } from '@ngrx/store';
import { Observable, of, Subscription } from 'rxjs';
import { catchError, exhaustMap, map, tap, take } from 'rxjs/operators';


import { MetaCrawler, MetaTargetServiceType, MetaInfraTypeEnum, toMetaInfraTypeEnum, toMetaInfraType, MetaTargetType } from '@overflow/commons-typescript/model/meta';
import { MetaCrawlerService } from '../service/meta-crawler.service';
import { MetaTargetTypeService } from '../service/meta-target-type.service';


@Component({
  selector: 'of-meta-service-type-selector',
  templateUrl: './meta-service-type-selector.component.html',
})
export class MetaServiceTypeSelectorComponent implements OnInit {

  @Output() selected = new EventEmitter<MetaCrawler>();

  metaTargetServiceTypes: MetaTargetServiceType[];
  pending$: Observable<boolean>;
  error$: Observable<any>;

  constructor(
    private metaTargetTypeService: MetaTargetTypeService,
  ) { }

  ngOnInit() {
    this.metaTargetTypeService.readAllByMetaInfraType
      (toMetaInfraType(MetaInfraTypeEnum.SERVICE))
      .pipe(
        tap(() => {
          this.pending$ = of(true);
        }),
        map((metaTargetTypes: MetaTargetType[]) => {
          this.metaTargetServiceTypes = metaTargetTypes;
          console.log(this.metaTargetServiceTypes);
        }),
        catchError(error => {
          this.error$ = of(error);
          return of();
        }),
        tap(() => {
          this.pending$ = of(false);
        }),
        take(1),
    ).subscribe();
  }

}
